pub unsafe extern "C-unwind" fn lua_pushinteger(
state: *mut _LuaState,
n: LuaInteger,
)Expand description
Pushes an integer with value n onto the stack.
pub unsafe extern "C-unwind" fn lua_pushinteger(
state: *mut _LuaState,
n: LuaInteger,
)Pushes an integer with value n onto the stack.