LuaDebug

Struct LuaDebug 

#[repr(C)]
pub struct LuaDebug { pub name: *const c_char, pub what: *const c_char, pub source: *const c_char, pub short_src: *const c_char, pub linedefined: c_int, pub currentline: c_int, pub nupvals: c_uchar, pub nparams: c_uchar, pub isvararg: c_char, pub userdata: *mut c_void, pub ssbuf: [c_char; 256], }

Fields

name: *const c_char

Field ‘n’

Name of the current function

what: *const c_char

Set by field ‘s’

Returns the “kind” of execution

Values are: “Luau”, “C”, “main”, “tail”

source: *const c_char

Set by field ‘s’

The source (chunkname) of an error.

Tf the error is from a C function will be set to ‘=[C]’

short_src: *const c_char

Set by field ‘s’

Truncated form of the chunkname with some additional formatting rules not exceeding LUA_IDSIZE in length

linedefined: c_int

Set by field ‘s’

The line on which the function was defined

currentline: c_int

Set by field ‘l’

Returns the current line in execution

nupvals: c_uchar

Set by field ‘u’

The number of upvalues for the function

nparams: c_uchar

Set by field ‘a’

The number of params accepted by the function

isvararg: c_char

Set by field ‘a’

1 if the function is a vararg function

0 if it is not

userdata: *mut c_void

Userdata field for lua_Debug

Is only valid for luau_callhook

ssbuf: [c_char; 256]

Buffer used for short_src operation